| MEDITS.to.dd | R Documentation |
Conversion of MEDITS format coordinates in decimal degrees format
MEDITS.to.dd(data)
data |
data frame of the hauls data (TA, table A) in MEDITS format |
The function returns the data frame of the TA table with the coordinates expressed as decimal degrees.
Walter Zupa
MEDITS.to.dd(TA)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.