| Maturity_parameters | R Documentation |
Maturity parameters used for the checks: check_smallest_mature, check_spawning_period and check_sex_inversion
data("Maturity_parameters")
A data frame with 64 observations on the following 12 variables.
Speciesa factor with levels the rubincodes of the species for which the information is known.
SEXa factor with levels C F M
min_L50a numeric vector
max_L50a numeric vector
smallest_mature_individual_observeda numeric vector
min_length_SEX_INVERSIONa numeric vector
max_length_SEX_INVERSIONa numeric vector
Type_of_hermaphroditisma factor with levels proterandrous protogynous
Areaa factor with levels as the area of the relevant information
Start_reproductive_seasona numeric vector
End_reproductive_seasona numeric vector
Referencea factor with levels of the bibliographic references
W. Zupa
Literature and others
data(Maturity_parameters)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.