| RSufi_files | R Documentation |
When the check procedure is completed for a number of years, it is possible to obtain the 4 R-Sufi global files from an year to another year.
RSufi_files(Year_start,Year_end,AREA,wd)
Year_start |
Start year |
Year_end |
Start end |
AREA |
String of the GSA. Include only the number. |
wd |
working directory path defined by the user |
The function saves automatically in the files R-Sufi folder the 4 global files, with suffix of the year range and GSA.
I. Bitetto, W. Zupa
Rochet M. J., V. M. Trenkel, J. A. Bertrand & J.-C. Poulard, 2004. R routines for survey based fisheries population and community indicators (R-SUFI). Ifremer, Nantes. Limited distribution. Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
TA = RoME::TA
TB = RoME::TB
TC = RoME::TC
DataSpecies=RoME::TM_list
Stratification=RoME::stratification_scheme
year = 2012
wd <- tempdir()
create_haul(TA,year,wd,save=TRUE)
create_catch(TB,year,wd,save=TRUE)
create_length(TC,year,DataSpecies,wd,save=TRUE)
create_strata(Stratification,"10",wd,save=TRUE)
RSufi_files(2012,2012,"10",wd) # run only if you are working outside a temporary directory
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.