assTL: TL association between categories and sub-categories

assTLR Documentation

TL association between categories and sub-categories

Description

List of the allowed association between categories and subcategories in litter data table (TL)

Usage

data("assTL")

Format

A data frame with 42 observations on the following 2 variables.

LITTER_CATEGORY

List of litter categories

⁠LITTER_SUB-CATEGORY⁠

List of litter sub-categories

Details

The table is used to check the correctness of the categories/sub-categories associations in litter data tables (TL).

Author(s)

W. Zupa

Anonymus (2017) "MEDITS-Handbook. Version n. 9. MEDITS Working Group"

References

Anonymus (2017) "MEDITS-Handbook. Version n. 9. MEDITS Working Group"

Examples

data(assTL)
str(assTL)

RoME documentation built on July 23, 2026, 5:07 p.m.

Related to assTL in RoME...