Learn R Programming

RoME (version 0.2.4)

checkHeader: Function to check the correctness of the headers.

Description

Function to check the correctness of the headers for haul data (TA), catch data (TB), biological data (TC), individual data (TE), litter data (TL) tables.

Usage

checkHeader(dataframe, template,wd,suffix)

Value

The function returns TRUE if no error occurs, while FALSE is returned when there is more than one valid hauls. In the logfile and in the console is reported the list of all the records in which the inconsistency is detected.

Arguments

dataframe

Table to check

template

Template used for the check.

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

This function produce an error, stopping the check procedure to avoid cascade errors.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
checkHeader(RoME::TA,"TA",wd,suffix)
checkHeader(RoME::TB,"TB",wd,suffix)
checkHeader(RoME::TC,"TC",wd,suffix)

Run the code above in your browser using DataLab