check_G1_G2: Check of length measurements for G1 and G2 species
Description
Check if for G1 and G2 species the length measurements are present in TC
Usage
check_G1_G2(DataTC, year, wd, suffix)
Value
The function returns always TRUE because the outcome of the function is a warning that does not block the execution of the 'RoME' checks. If the length is lacking for any species in any haul, a warning message is given in the logfile.
Arguments
DataTC
Biological data table according to MEDITS protocol (TC)
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
Author
I. Bitetto, W. Zupa
Details
This check uses a new support table (list_g1_g2) containing the list of MEDITS G1 and G2 species and verify if the length has been collected for the selected species for each haul. If the length is lacking for any species in any haul, a warning message is given in the logfile.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.