Learn R Programming

RoME (version 0.2.4)

check_TE_TC: Function to verify the consistency between individual data table (TE) and biological data table (TC) respect to number of individuals.

Description

Check if the individuals by species, length, sex and maturity stage reported in TE are less than the number reported in TC

Usage

check_TE_TC(ResultDataTC,ResultDataTE,year,wd,suffix)

Value

The function returns TRUE if there is no error, while FALSE if there is one or more errors.The run, in case of error, thus, is stopped.

Arguments

ResultDataTC

Biological data table(TC).

ResultDataTE

Individual data table (TE).

year

reference year for the analysis.

wd

Working directory selected by the user.

suffix

Suffix string of the Logfile.

Author

I. Bitetto, W. Zupa

Details

This function gives an error message, thus the execution is stopped if in TE are reported individuals not present in TC and if the number of individuals reported in TE is greater than the ones in TE; the user is informed in the Logfile.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
tc <- RoME::TC
te <- RoME::TE
year=2012
check_TE_TC(tc,te,year,wd,suffix)

Run the code above in your browser using DataLab