Learn R Programming

RoME (version 0.2.4)

check_area: Check if TX files have the same area

Description

The function works with data of a single year of survey and checks if TX files have the same area code.

Usage

check_area(DataTA, DataTB, DataTC, DataTE=NA, DataTL=NA, year, wd, suffix)

Value

The function returns TRUE if no error occurs, while FALSE is returned when there are differences in the AREA code among the TX tables.

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

DataTB

Catch data table according to MEDITS protocol (TB)

DataTC

Biological data table according to MEDITS protocol (TC)

DataTE

Individual biological data table according to MEDITS protocol (TE)

DataTL

Litter data table according to MEDITS protocol (TL)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

TA, TB and TC tables are mandatory while TE and TL could be used where available.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    DataTA = RoME::TA
    DataTB = RoME::TB
    DataTC = RoME::TC
    DataTE = RoME::TE
    DataTL = RoME::TL
    check_area(DataTA, DataTB,DataTC,DataTE=NA,DataTL=NA,year=2012, wd, suffix)

Run the code above in your browser using DataLab