check_associations_category_TL: Check correctness of TL categories

View source: R/check_associations_category_TL.r

check_associations_category_TLR Documentation

Check correctness of TL categories

Description

Check correctness of association between category and sub-category in TL consistent according to INSTRUCTION MANUAL VERSION 9

Usage

check_associations_category_TL(DataTL, assTL, year, wd, suffix)

Arguments

DataTL

Litter data table (TL) according to MEDITS protocol.

assTL

data frame with the association between TL (litter table) categories and sub-categories

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Details

The package uses a table of association between TL categories and sub-categories that is resident in the data folder of the package as assTL.rda file.

Value

The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles"" subdirectory of the "wd"" user-defined directory.

Author(s)

I. Bitetto, W. Zupa

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples


    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    DataTL = RoME::TL
    check_associations_category_TL(DataTL, assTL, year=2012, wd, suffix)


RoME documentation built on April 24, 2026, 1:07 a.m.