Learn R Programming

RoME (version 0.2.4)

check_bridles_length: check of bridles length correctness

Description

The function performs consistency checks of the values in the "BRIDLES_LENGTH" field of the hauls data table (TA).

Usage

check_bridles_length(DataTA, year, wd, suffix)

Value

The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles"" subdirectory of the "wd"" user-defined directory.

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

year

reference year for the analysis

Author

I. Bitetto, W. Zupa

Details

The field BRIDLES_LENGTH can assume value 100 between 10-200 m of depth or 150 between 200-800 m. The function highlights also that MEDITS handbook recommends to increase the bridle length to 200 m in depths deeper than 500 m, reporting a warning in the logfile. Empty (NA) records in "BRIDLES_LENGTH" will be eliminated being the presence of empty fields already checked by check_no_empty_fields

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
check_bridles_length(RoME::TA, year=2012, wd, suffix)

Run the code above in your browser using DataLab