View source: R/check_consistencyTA_distance.r
| check_consistencyTA_distance | R Documentation |
The function checks whether the distances reported in the haul data (TA) are consistent with the hauls duration.
check_consistencyTA_distance(DataTA, year, wd, suffix)
DataTA |
Haul data table according to MEDITS protocol (TA) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
Check between duration of the haul and distance (tolerance of 15%). The function does not check the presence of NA values in the DISTANCE field that are removed from the analysis. The eventual presence of empty records in the DISTANCE field is checked by the check_no_empty_fields function.
The function generates warning messages in the logfile and returns always TRUE.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd=tempdir()
suffix="2020-03-05_time_h17m44s55"
check_consistencyTA_distance(RoME::TA,year=2012,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.