Check if in TB, TC and TE the date by haul is the same of the one reported in TA
Usage
check_date_haul(DataTA, Data, year, wd, suffix)
Value
The function returns TRUE if no error occurs, while FALSE is returned when in the Date data frame there is one or more date not included in the TA tables.
Arguments
DataTA
Haul data table according to MEDITS protocol (TA)
Data
Data frame of one of the following TX table: TB, TC, TE, TL
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
Author
I. Bitetto, W. Zupa
Details
The function check whether in one of the TX file allowed in Data argument there are date consistent with the one reported in the haul data table (TA).
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.