Learn R Programming

RoME (version 0.2.4)

check_dm: Check of "WING_OPENING" and "VERTICAL_OPENING" fields

Description

The function checks the values in "WING_OPENING" and "VERTICAL_OPENING" field are in the allowed ranges (see INSTRUCTION MANUAL VERSION 9 MEDITS 2017).

Usage

check_dm(DataTA, year, wd, suffix)

Value

The function returns an error in case wing values are out of the allowed ranges, while it returns warnings in case vertical opening values are out of the allowed ranges and in case wing opening and vertical opening values are not integer numbers.

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

The value ranges defined in the INSTRUCTION MANUAL VERSION 9 MEDITS (2017) for wing and vertical opening expressed in dm are respectively 50 - 250 and 10 - 100.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd=tempdir()
suffix="2020-12-16_time_h10m52s55"
check_dm(RoME::TA,year=2007,wd,suffix)

Run the code above in your browser using DataLab