check_haul_species_TCTB: Check species of TC in TB

View source: R/check_haul_species_TCTB.r

check_haul_species_TCTBR Documentation

Check species of TC in TB

Description

The function checks whether all the species present in TC (biological data table) must be listed in TB (catch data table)

Usage

check_haul_species_TCTB(DataTB, DataTC, year, wd, suffix)

Arguments

DataTB

catch data table according to MEDITS protocol (TB)

DataTC

Biological data table according to MEDITS protocol (TC)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Details

The function returns a warning message in the logfile.

Value

If a species present in the TC table (biological data table) is not reported in the TB (catch data table) an error message is reported in the logfile and a "Critical_errors" file is saved in the working directory reporting details on the errors.

Author(s)

I. Bitetto, W. Zupa

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples

wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
year=2008
check_haul_species_TCTB(RoME::TB, RoME::TC, year, wd, suffix)

RoME documentation built on April 24, 2026, 1:07 a.m.