View source: R/check_hauls_TATL.r
| check_hauls_TATL | R Documentation |
Check if the hauls in TA are present in TL
check_hauls_TATL(DataTA, DataTL, year, wd, suffix)
DataTA |
Haul data table according to MEDITS protocol (TA) |
DataTL |
Litter data table according to MEDITS protocol (TL) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The function checks whether all the hauls present in hauls data table (TA) are included in the litter data table (TL).
The function returns always TRUE because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The list of the hauls not present in the TL table is reported in the logfile stored in the "Logfiles"" subdirectory of the "wd" user-defined directory.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
DataTA = RoME::TA
DataTL = RoME::TL
year=2008
check_hauls_TATL(DataTA,DataTL,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.