check_hauls_TLTA: Check presence of TL hauls in TA

View source: R/check_hauls_TLTA.r

check_hauls_TLTAR Documentation

Check presence of TL hauls in TA

Description

Check if the hauls in TL are present in TA

Usage

check_hauls_TLTA(DataTA,DataTL,year,wd,suffix)

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

DataTL

Litter data table according to MEDITS protocol (TL)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Details

The function checks whether all the hauls present in litter data table (TL) are included in the haul data table (TA).

Value

The function returns TRUE if no error occurs, while FALSE is returned when there are missing hauls in the TA table.

Author(s)

I. Bitetto, W. Zupa

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples


    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    DataTA = RoME::TA
    DataTL = RoME::TL
    year=2008
    check_hauls_TLTA(DataTA,DataTL,year,wd,suffix)


RoME documentation built on April 24, 2026, 1:07 a.m.