Learn R Programming

RoME (version 0.2.4)

check_identical_records: Check of identical records in TX tables

Description

The function checks whether there is one or more identical records in the selected type of table (TX).

Usage

check_identical_records(Data, year, wd, suffix)

Value

The function returns TRUE if no error occurs, while FALSE is returned when there is one or more identical record in the given TX table.

Arguments

Data

one of the different data tables defined by the MEDITS protocol (TX)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

The routine uses all the table format (TX) defined by the MEDITS protocol.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    Data = RoME::TA
    check_identical_records(Data, year=2007, wd, suffix)

Run the code above in your browser using DataLab