The file Comparison_estimated_observed_weight_in_TC.csv is automatically saved in the working directory in order to easily detect the samples with this differences in total weight. For all the records the percentage difference between observed and estimated weight is reported.
Arguments
DataTC
Biological data table according to MEDITS protocol (TC)
LW
data frame of the a and b parameters by species, area and sex
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
verbose
boolean parameter, if TRUE returns messages about the progress of the elaboration
Author
I. Bitetto, W. Zupa
Details
The warning is given when difference between the sum of estimated individual weights (by haul, species and sub-samples) and the WEIGHT_OF_THE_SAMPLE_MEASURED is greater than 50% for at least one record. This check is based on the table LW contained in package, where the length-weight relationship coefficients are reported by species, area and sex.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.