If for at least one record the difference between observed and estimated individual weight is greater than 20% a warning is given in Logfile.dat and a table named TE_with_estimated_weights.csv is automatically produced in order to allow the user to easily eventually detect the errors. For all the records the percentage difference between observed and estimated weight is reported.
Arguments
DataTE
Individual biological data table according to MEDITS protocol (TE)
LW
data frame of the length-weight parameters by species, area and sex
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
verbose
boolean parameter, if TRUE returns messages about the progress of the elaboration
Author
I. Bitetto, W. Zupa
Details
For each individual is calculated the estimated weight according to length-weight relationship coefficient stored in LW table and the difference between observed and estimated individual weight in percentage. Moreover, this function checks if for G1 species has been collected the weight or if has been entered the value ND, that is not allowed.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.