Learn R Programming

RoME (version 0.2.4)

check_length_class_codeTC: Consistency check of LENGTH_CLASS

Description

The function checks the consistency of field LENGTH_CLASSES_CODE in TC

Usage

check_length_class_codeTC(DataTC,Specieslist=RoME::TM_list,year,wd,suffix)

Value

If the LENGTH_CLASS_CODE in TC table (biological data table) are not consistent with CODLON field in Specieslist dataset (or TM_list if Specieslist is NA) an error is returned. In case a LENGTH_CLASS_CODE is not reported for the given species no check is done and the function returns a warning message.

Arguments

DataTC

Biological data table according to MEDITS protocol (TC)

Specieslist

Information related to target species as reported in the TM list

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

The function checks whether the LENGTH_CLASS_CODE by species are consistent with those reported in the Specieslist dataset. When Specieslist is NA the TM_list dataset (included in the package) is used by default.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
# \donttest{
DataTC <- RoME::TC
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
check_length_class_codeTC(DataTC,Specieslist=NA,year=2007,wd,suffix)
# }

Run the code above in your browser using DataLab