The function always returns TRUE generating a warning message when inconsistencies in the maturity stages are detected, being difficult to define for all GSAs the year in which occurred the switch from the "old" MEDITS maturity scale to the current MEDITS scale.
Arguments
Data
Biological data table (TC) or individual biological data table (TE) according to MEDITS protocol
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
stages
data frame with the list of allowed maturity stages for faunistic category as defined by the mat_stages dataset included in the package
Author
I. Bitetto, W. Zupa
Details
The check on maturity stage is performed for the species included in the new TM list, where selachians and bony fish are distinguished. The check is applied to the following faunistic categories: Ao, Ae, B, C and Bst.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.