check_nb_TE: Consistency of number of individuals sampled for weight and...

check_nb_TER Documentation

Consistency of number of individuals sampled for weight and ageing in TE

Description

The function checks the consistency of number of individuals sampled for weight and ageing in TE

Usage

check_nb_TE(DataTE, year, wd, suffix)

Arguments

DataTE

Individual biological data table according to MEDITS protocol (TE)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Details

this function verify the consistency of the check-fields:

  • NO_PER_SEX_MEASURED_IN_SUB_SAMPLE_FOR_OTOLITH

  • NO_PER_SEX_MEASURED_IN_SUB_SAMPLE_FOR_WEIGHT

  • NO_PER_SEX_MEASURED_IN_SUBSAMPLE_FOR_AGEING

These fields are compared to the number of records present in TE by sex, length class and haul.

Value

The function returns FALSE in case inconsistencies are detected in the individual biological data table (TE)

Author(s)

I. Bitetto, W. Zupa

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples


    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    DataTE = RoME::TE
    year=2012
    check_nb_TE(DataTE,year, wd, suffix)


RoME documentation built on April 24, 2026, 1:07 a.m.