View source: R/check_nbtotTB.r
| check_nbtotTB | R Documentation |
The function checks that the total number of individuals is consistent with the sum of the individuals per sex
check_nbtotTB(DataTB, year, wd, suffix)
DataTB |
Catch data table according to MEDITS protocol (TB) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The function checks that the total number of individuals is consistent with the sum of the individuals per sex
The function returns TRUE if no error occurs, FALSE if one or more inconsistencies in the individuals number is detected.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
DataTB = RoME::TB
year=2007
check_nbtotTB(DataTB,year, wd, suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.