| check_nm_TB | R Documentation |
Check if in TB there are the total number, number of females, males and undetermined for species G1
check_nm_TB(DataTB, year, wd, suffix)
DataTB |
Catch data table according to MEDITS protocol (TB) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
for the species G1 are not allowed that the fields related to total number, number of females, number of males and number of undetermined are simultaneously null, according to MEDITS manual version 9 of 2017.
The function returns TRUE if no error occurs, FALSE if one or more inconsistencies in the individuals number per sex in TB is detected.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
DataTB = RoME::TB
year=2007
check_nm_TB(DataTB, year, wd, suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.