View source: R/check_position.r
| check_position | R Documentation |
The function generate three different plots, haul start position, haul end position and start and end positions together.
check_position(DataTA, year, wd, suffix)
DataTA |
Haul data table according to MEDITS protocol (TA) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The haul position maps are saved in the Graph directory allocated in the user defined wd directory.
The function generate three maps of the haul position that are stored in the Graph folder allocated in the user defined wd directory
W. Zupa, I. Bitetto
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
year=2007
check_position(RoME::TA,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.