check_position_in_Med: Check of haul position in Mediterranean Sea

View source: R/check_position_in_Med.r

check_position_in_MedR Documentation

Check of haul position in Mediterranean Sea

Description

The function checks whether the position of the haul is in the Mediterranean Sea area or falls on the land.

Usage

check_position_in_Med(DataTA, year, wd, suffix)

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Details

The function uses the haul_at_sea() function to check whether the position of the haul is in the Mediterranean Sea area or falls on the land.

Value

The function returns a boolean value. It is FALSE in case one or more haul positions fall out of the Mediterranean Sea area defined by the shapefile MedSea included in the package.

Author(s)

W. Zupa, I. Bitetto

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples

    wd <- tempdir()
    suffix="2020-03-05_time h17m44s55"
    DataTA = RoME::TA
    year=2007
    check_position_in_Med(DataTA, year, wd, suffix)

RoME documentation built on April 24, 2026, 1:07 a.m.