View source: R/check_species_TBTC.r
| check_species_TBTC | R Documentation |
This function verifies the presence of the target species (that is a subset of the all the species caught, reported in TB), in the TC table, where additional information (apart from number and weight) are collected.
check_species_TBTC(ResultTB,ResultTC,year,DataSpecies,wd,suffix)
ResultTB |
Catch data table(TB). |
ResultTC |
Biological data table (TC). |
year |
reference year for the analysis |
DataSpecies |
Information related to target species. |
wd |
Working directory selected by the user. |
suffix |
Suffix string of the Logfile. |
This function gives a warning message, thus the execution is not stopped when some target species are lacking in TC; the user is informed in the Logfile.
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd=tempdir()
suffix = "2020-03-05_time_h17m44s55"
year=2007
ResultTB=RoME::TB
ResultTC=RoME::TC
check_species_TBTC(ResultTB,ResultTC,year,RoME::DataTargetSpecies,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.