Learn R Programming

RoME (version 0.2.4)

check_stratum: Function that checks the consistency between start and end depth according to the stratum.

Description

Start depth and end depth of each haul should be in the same stratum.

Usage

check_stratum(ResultData,year,wd,suffix)

Value

The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles" subdirectory of the "wd" user-defined directory.

Arguments

ResultData

Haul data table according to MEDITS protocol (TA).

year

reference year for the analysis

wd

Working directory selected by the user.

suffix

Suffix string of the Logfile.

Author

I. Bitetto, W. Zupa

Details

Start depth and end depth of each haul should be in the same stratum. The strata are the ones defined according to the MEDITS protocol: 10-15 m; 50-100 m; 100-200 m; 200-500m; 500-800 m.

References

For the definition of the strata, please refer to: Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd=tempdir()
year=2007
TA = RoME::TA
suffix= "2020-03-05_time_h17m44s55"
check_stratum(TA,year,wd,suffix)

Run the code above in your browser using DataLab