View source: R/check_subsampling.r
| check_subsampling | R Documentation |
Check if the sub-sample is smaller than the 10 percent of the total weight in the haul.
check_subsampling(ResultTC,year,wd,suffix)
ResultTC |
Biological data table (TC). |
year |
reference year for the analysis. |
wd |
Working directory selected by the user. |
suffix |
Suffix string of the Logfile. |
This function give a warning, reported in the Logfile, if the sub-sample is unusually small respect to the total catch of the species.
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles" subdirectory of the "wd" user-defined directory.
I. Bitetto, W. Zupa
For the definition of the strata, please refer to: Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
TC = RoME::TC
year=2007
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
check_subsampling(TC,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.