| check_temperature | R Documentation |
This function checks if the temperature by haul is in the range 10-30 Celsius degrees; moreover, a plot depth versus temperature is produced and stored in the Graph folder.
check_temperature(ResultDataTA,year,wd,suffix)
ResultDataTA |
Haul data table according to MEDITS protocol (TA). |
year |
reference year for the analysis. |
wd |
Working directory selected by the user. |
suffix |
Suffix string of the Logfile. |
This check uses the temperature range 10-30 Celsius degrees to provide quantitative warning and a plot, automatically stored in Graphs, for a qualitative inspection of that temperature data respect to depth.
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles" subdirectory of the "wd" user-defined directory.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
TA = RoME::TA
year=2012
wd=tempdir()
suffix="2020-03-05_time_h17m44s55"
check_temperature(TA,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.