check_unique_valid_haul: Function checking that among hauls with the same code, only...

View source: R/check_unique_valid_haul.r

check_unique_valid_haulR Documentation

Function checking that among hauls with the same code, only one must be valid.

Description

Check the presence of unique valid haul codes.

Usage

check_unique_valid_haul(ResultDataTA,year,wd,suffix)

Arguments

ResultDataTA

Haul data table according to MEDITS protocol (TA).

year

reference year for the analysis.

wd

Working directory selected by the user.

suffix

Suffix string of the Logfile.

Details

This function produce an error, stopping the check procedure to avoid cascade errors.

Value

The function returns TRUE if no error occurs, while FALSE is returned when there is more than one valid hauls. In the logfile is reported the list of all the records in which the inconsistency is detected.

Author(s)

I. Bitetto, W. Zupa

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples

TA = RoME::TA
year=2012
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
check_unique_valid_haul(TA,year,wd,suffix)

RoME documentation built on April 24, 2026, 1:07 a.m.