View source: R/check_weight_tot_nb.r
| check_weight_tot_nb | R Documentation |
If total weight is different from 0, total number must be different from 0 (only if the category of the species is different from "E") and vice versa (for all faunistic categories).
check_weight_tot_nb(ResultDataTB,year,wd,suffix)
ResultDataTB |
Catch data table according to MEDITS protocol (TB) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
In this check 'RoME' verifies if for the records with total weight not null, there is a total number not null, except for categories V, G, H, D and E, as reported in MEDITS manual.
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd=tempdir()
year=2012
TB = RoME::TB
suffix= "2020-03-05_time_h17m44s55"
check_weight_tot_nb(TB,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.