| check_year | R Documentation |
The function check if the correct value for YEAR field is reported in each data table. This is a global function that runs with the data frames not filtered by year.
check_year(TA, TB, TC, TE, TL, years, wd, Errors)
TA |
Haul data table according to MEDITS protocol (TA) |
TB |
Catch data table according to MEDITS protocol (TB) |
TC |
Biological data table according to MEDITS protocol (TC) |
TE |
Individual biological data table according to MEDITS protocol (TE) |
TL |
Litter data table according to MEDITS protocol (TL) |
years |
list of the unique YEAR values in haul data (TA) table |
wd |
working directory path defined by the user |
Errors |
logfile name |
TA, TB and TC tables are mandatory while TE and TL could be used where available (otherwise use NA value).
The function returns FALSE when errors are detected in the YEAR field of the data tables.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
years <- unique(RoME::TA$YEAR)
Errors <- file.path(wd,"Logfiles","Logfile.dat")
check_year(TA=RoME::TA, TB=RoME::TB,
TC=RoME::TC, TE=NA, TL=NA, years=years,
wd=wd, Errors=Errors)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.