create_catch: Function to create the R-sufi file capt.
Description
This function report the information contained in the biological data table (TB) from the MEDITS protocol to the format required by R-sufi (Rochet et al., 2004).
Usage
create_catch(ResultDataTB,year,wd,save=TRUE)
Value
The function saves by default in the files R-Sufi folder the table capt in.csv format, with suffix of the year and GSA. If save parameter is FALSE the function returns the data frame as output.
Arguments
ResultDataTB
Catch data table according to MEDITS protocol (TB)
year
reference year for the analysis
wd
working directory path defined by the user
save
boolean value to save the results in a csv file
Author
I. Bitetto, W. Zupa
References
Rochet M. J., V. M. Trenkel, J. A. Bertrand & J.-C. Poulard, 2004. R routines for survey based fisheries population and community indicators (R-SUFI). Ifremer, Nantes. Limited distribution.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.