| error.table | R Documentation |
Function generating the error summary table.
error.table(check.df,check_without_errors,
check_without_warnings,checkName,table,Field,yea)
check.df |
data frame of the checks |
check_without_errors |
boolean variable reporting if errors were detected |
check_without_warnings |
boolean variable reporting if warnings were detected |
checkName |
string of the check name |
table |
reference table checked by the function |
Field |
field checked by check dictionary |
yea |
reference year |
The function generate the summary table of the errors detected by the RoMEcc function.
The output of the function is the data frame check.df updated with the result of the check.
W. Zupa, I. Bitetto
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.