| graphs_TA | R Documentation |
Qualitative control (by means of 2 graphs) of relation between shooting depth e warp opening and between warp length e wing opening
graphs_TA(DataTA, year, wd, suffix)
DataTA |
Haul data table according to MEDITS protocol (TA) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The function generate 2 graphs for qualitative controls.
Two graphs are stored in the Graphs folder in the wd user defined directory
W. Zupa, I. Bitetto
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
TA = RoME::TA
year = 2012
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
graphs_TA(RoME::TA,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.