| haul_at_sea | R Documentation |
The function identify the hauls that don't fall in the user defined sea area.
haul_at_sea(DataTA,year,seas=RoME::MedSea,verbose = TRUE)
DataTA |
Haul data table according to MEDITS protocol (TA) |
year |
reference year for the analysis |
seas |
polygon shapefile defining the extension of the sea area. The default |
verbose |
boolean variable returning verbose output if TRUE |
The function check whether the haul position falls in the polygon seas defining the extension of the reference sea area.
The function returns the list of the hauls out of the seas polygon. In case only starting haul positions are out of the sea's area a data frame is returned. If both starting and end positions are out of the polygon an object of class list is returned.
W. Zupa, I. Bitetto
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
TA = RoME::TA
year = 2012
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
haul_at_sea(TA,year, seas = MedSea, verbose = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.