headers.conversion: Headers conversion for MEDITS tables

View source: R/header.conversion.r

headers.conversionR Documentation

Headers conversion for MEDITS tables

Description

Headers conversion for MEDITS tables

Usage

headers.conversion(table, type, verbose = FALSE)

Arguments

table

data frame of the TX table

type

type of tables to be analysed. Allowed values: "TA","TB","TC","TE","TL"

verbose

boolean. If TRUE a message is printed.

Details

The functions allow to convert headers of table coming from RDBFIS data base to the MEDITS format expected from RoME package

Value

A data frame object is returned including the only allowed field


RoME documentation built on April 24, 2026, 1:07 a.m.