Learn R Programming

RoME (version 0.2.4)

scheme_individual_data: Summary of the individual data collected by species

Description

Check for summarize the individual data collection (goodness of individual data sampling)

Usage

scheme_individual_data(DataTC, DataTE, year, wd, suffix)

Value

This check has as output a table (automatically saved in the wd user defined directory) named sampling_individual_measures.csv where for each species are stored the number of length measurements, individual weights and number of otoliths taken by length class. This table is useful to the user to evaluate the coverage of the individual measurements collections in order to verify if the sampling is in line with the protocol and to understand how eventually improve the sampling procedure.

Arguments

DataTC

Biological data table according to MEDITS protocol (TC)

DataTE

Individual biological data table according to MEDITS protocol (TE)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

The function uses biological data and individual biological data to produce a table where for each species are stored the number of length measurements, individual weights and number of otoliths taken by length class.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
# \donttest{
    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    DataTC = RoME::TC
    DataTE = RoME::TE
    year=2012
    scheme_individual_data(DataTC,DataTE,year, wd, suffix)
# }

Run the code above in your browser using DataLab