| DataTargetSpecies | R Documentation |
Data frame containing information about length and individual weight ranges for relevant species, including quantiles and various statistics. It also contains metadata about faunistic category and period of relevance as target species.
data("DataTargetSpecies")
A data frame with 392 observations on the following 26 variables:
SPECIESRubincode species identifier (character).
WMINMinimum observed individual weight (numeric).
WMIN055th percentile of individual weight (numeric).
WMIN1010th percentile of individual weight (numeric).
WMIN2525th percentile of individual weight (numeric).
WMAX_7575th percentile of individual weight (numeric).
WMAX9090th percentile of individual weight (numeric).
WMAX9595th percentile of individual weight (numeric).
WMAXMaximum observed individual weight (numeric).
LMINMinimum observed length (numeric, in mm).
LMIN011st percentile of length (numeric, in mm).
LMIN055th percentile of length (numeric, in mm).
LMIN1010th percentile of length (numeric, in mm).
LMIN2525th percentile of length (numeric, in mm).
LMAX7575th percentile of length (numeric, in mm).
LMAN9090th percentile of length calculated via mean or other method (numeric, in mm).
LMAX9595th percentile of length (numeric, in mm).
LMAX9999th percentile of length (numeric, in mm).
LMAXMaximum observed length (numeric, in mm).
obs_in_TCNumber of observations found in TC data (numeric).
FAUNISTIC_CATEGORYOld faunistic categories (character).
START_YEARYear when the species started to be considered target (numeric).
END_YEARYear when the species stopped being considered target (numeric).
GROUPSpecies group or classification (character).
W. Zupa
Literature and other data sources.
data(DataTargetSpecies)
head(DataTargetSpecies)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.