Learn R Programming

RoME (version 0.2.4)

MEDITS.to.dd: Conversion of MEDITS format coordinates in decimal degrees format

Description

Conversion of MEDITS format coordinates in decimal degrees format

Usage

MEDITS.to.dd(data)

Value

The function returns the data frame of the TA table with the coordinates expressed as decimal degrees.

Arguments

data

data frame of the hauls data (TA, table A) in MEDITS format

Author

Walter Zupa

Examples

Run this code
MEDITS.to.dd(TA)

Run the code above in your browser using DataLab