powered by
Conversion of MEDITS format coordinates in decimal degrees format
MEDITS.to.dd(data)
The function returns the data frame of the TA table with the coordinates expressed as decimal degrees.
data frame of the hauls data (TA, table A) in MEDITS format
Walter Zupa
MEDITS.to.dd(TA)
Run the code above in your browser using DataLab