powered by
Maturity parameters used for the checks: check_smallest_mature, check_spawning_period and check_sex_inversion
data("Maturity_parameters")
A data frame with 64 observations on the following 12 variables.
Species
a factor with levels the rubincodes of the species for which the information is known.
SEX
a factor with levels C F M
C
F
M
min_L50
a numeric vector
max_L50
smallest_mature_individual_observed
min_length_SEX_INVERSION
max_length_SEX_INVERSION
Type_of_hermaphroditism
a factor with levels proterandrous protogynous
proterandrous
protogynous
Area
a factor with levels as the area of the relevant information
Start_reproductive_season
End_reproductive_season
Reference
a factor with levels of the bibliographic references
W. Zupa
data(Maturity_parameters)
Run the code above in your browser using DataLab