| TM_list | R Documentation |
The present list is destined to code the marine species encountered in the Mediterranean. It has been built following the principle used in the Nordic Code Centre (Stockholm). For most of the species the codes are identical to those proposed by the NCC. However some species can be coded differently. In addition numerous Mediterranean species are not included in the NCC code and have been added. So the present list is specific. It has to be referred as the TM list (Taxonomic list not only Faunistic, FM list).
data("TM_list")
A data frame with 1470 observations on the following 11 variables.
N.a numeric vector
MeditsCodea factor with levels of species codes in the RUBIN format (see MEDITS manual)
Scientific.Name.................................................valida factor with levels of the scientific names of the species
Authorshipa factor with levels of the authorship of the information
Sourcea factor with levels sources of the information
Referencea factor with levels of the bibliographic references
Remarksa factor with levels the reported remarks
CATFAUa factor with levels of the faunistic categories of the species
CODLONa factor with CODLON that represents the Length classes code: m = 1 mm; 0 = 0,5 cm; 1 = 1 cm.
GSAsa factor with levels of the Geographic Sub-Areas (GSA) adopted in the MEDITS protocol.
Yeara factor with levels of the years
W. Zupa
MEDITS MEDITS-Handbook, Version n. 9 (2017)
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
data(TM_list)
str(TM_list)
head(TM_list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.