| assTL | R Documentation |
List of the allowed association between categories and subcategories in litter data table (TL)
data("assTL")
A data frame with 42 observations on the following 2 variables.
LITTER_CATEGORYList of litter categories
List of litter sub-categories
The table is used to check the correctness of the categories/sub-categories associations in litter data tables (TL).
W. Zupa
Anonymus (2017) "MEDITS-Handbook. Version n. 9. MEDITS Working Group" https://www.sibm.it/MEDITS%202011/principaledownload.htm
Anonymus (2017) "MEDITS-Handbook. Version n. 9. MEDITS Working Group" https://www.sibm.it/MEDITS%202011/principaledownload.htm
data(assTL)
str(assTL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.