Learn R Programming

RoME (version 0.2.4)

assTL: TL association between categories and sub-categories

Description

List of the allowed association between categories and subcategories in litter data table (TL)

Usage

data("assTL")

Arguments

Format

A data frame with 42 observations on the following 2 variables.

LITTER_CATEGORY

List of litter categories

LITTER_SUB-CATEGORY

List of litter sub-categories

Author

W. Zupa

Details

The table is used to check the correctness of the categories/sub-categories associations in litter data tables (TL).

References

Anonymus (2017) "MEDITS-Handbook. Version n. 9. MEDITS Working Group"

Examples

Run this code
data(assTL)
str(assTL)

Run the code above in your browser using DataLab