powered by
List of the allowed association between categories and subcategories in litter data table (TL)
data("assTL")
A data frame with 42 observations on the following 2 variables.
LITTER_CATEGORY
List of litter categories
List of litter sub-categories
W. Zupa
The table is used to check the correctness of the categories/sub-categories associations in litter data tables (TL).
Anonymus (2017) "MEDITS-Handbook. Version n. 9. MEDITS Working Group"
data(assTL) str(assTL)
Run the code above in your browser using DataLab