The function returns TRUE if there is no error, while FALSE if there is one or more errors.The run, in case of error, thus, is stopped.
Arguments
ResultDataTC
Biological data table(TC).
ResultDataTE
Individual data table (TE).
year
reference year for the analysis.
wd
Working directory selected by the user.
suffix
Suffix string of the Logfile.
Author
I. Bitetto, W. Zupa
Details
This function gives an error message, thus the execution is stopped if in TE are reported individuals not present in TC and if the number of individuals reported in TE is greater than the ones in TE; the user is informed in the Logfile.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.