The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles"" subdirectory of the "wd"" user-defined directory.
Arguments
DataTL
Litter data table (TL) according to MEDITS protocol.
assTL
data frame with the association between TL (litter table) categories and sub-categories
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
Author
I. Bitetto, W. Zupa
Details
The package uses a table of association between TL categories and sub-categories that is resident in the data folder of the package as assTL.rda file.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.