View source: R/check_haul_species_TCTB.r
| check_haul_species_TCTB | R Documentation |
The function checks whether all the species present in TC (biological data table) must be listed in TB (catch data table)
check_haul_species_TCTB(DataTB, DataTC, year, wd, suffix)
DataTB |
catch data table according to MEDITS protocol (TB) |
DataTC |
Biological data table according to MEDITS protocol (TC) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The function returns a warning message in the logfile.
If a species present in the TC table (biological data table) is not reported in the TB (catch data table) an error message is reported in the logfile and a "Critical_errors" file is saved in the working directory reporting details on the errors.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
year=2008
check_haul_species_TCTB(RoME::TB, RoME::TC, year, wd, suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.