Learn R Programming

RoME (version 0.2.4)

check_haul_species_TCTB: Check species of TC in TB

Description

The function checks whether all the species present in TC (biological data table) must be listed in TB (catch data table)

Usage

check_haul_species_TCTB(DataTB, DataTC, year, wd, suffix)

Value

If a species present in the TC table (biological data table) is not reported in the TB (catch data table) an error message is reported in the logfile and a "Critical_errors" file is saved in the working directory reporting details on the errors.

Arguments

DataTB

catch data table according to MEDITS protocol (TB)

DataTC

Biological data table according to MEDITS protocol (TC)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

The function returns a warning message in the logfile.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
year=2008
check_haul_species_TCTB(RoME::TB, RoME::TC, year, wd, suffix)

Run the code above in your browser using DataLab