View source: R/check_hauls_TLTA.r
| check_hauls_TLTA | R Documentation |
Check if the hauls in TL are present in TA
check_hauls_TLTA(DataTA,DataTL,year,wd,suffix)
DataTA |
Haul data table according to MEDITS protocol (TA) |
DataTL |
Litter data table according to MEDITS protocol (TL) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The function checks whether all the hauls present in litter data table (TL) are included in the haul data table (TA).
The function returns TRUE if no error occurs, while FALSE is returned when there are missing hauls in the TA table.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
DataTA = RoME::TA
DataTL = RoME::TL
year=2008
check_hauls_TLTA(DataTA,DataTL,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.