powered by
Check if the hauls in TL are present in TA
check_hauls_TLTA(DataTA,DataTL,year,wd,suffix)
The function returns TRUE if no error occurs, while FALSE is returned when there are missing hauls in the TA table.
Haul data table according to MEDITS protocol (TA)
Litter data table according to MEDITS protocol (TL)
reference year for the analysis
working directory path defined by the user
Suffix string of the Logfile
I. Bitetto, W. Zupa
The function checks whether all the hauls present in litter data table (TL) are included in the haul data table (TA).
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.
# \donttest{ wd <- tempdir() suffix="2020-03-05_time_h17m44s55" DataTA = RoME::TA DataTL = RoME::TL year=2008 check_hauls_TLTA(DataTA,DataTL,year,wd,suffix) # }
Run the code above in your browser using DataLab