powered by
The function checks whether there is one or more identical records in the selected type of table (TX).
check_identical_records(Data, year, wd, suffix)
The function returns TRUE if no error occurs, while FALSE is returned when there is one or more identical record in the given TX table.
one of the different data tables defined by the MEDITS protocol (TX)
reference year for the analysis
working directory path defined by the user
Suffix string of the Logfile
I. Bitetto, W. Zupa
The routine uses all the table format (TX) defined by the MEDITS protocol.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.
wd <- tempdir() suffix="2020-03-05_time_h17m44s55" Data = RoME::TA check_identical_records(Data, year=2007, wd, suffix)
Run the code above in your browser using DataLab