powered by
The function checks the consistency of number of individuals sampled for weight and ageing in TE
check_nb_TE(DataTE, year, wd, suffix)
The function returns FALSE in case inconsistencies are detected in the individual biological data table (TE)
Individual biological data table according to MEDITS protocol (TE)
reference year for the analysis
working directory path defined by the user
Suffix string of the Logfile
I. Bitetto, W. Zupa
this function verify the consistency of the check-fields:
NO_PER_SEX_MEASURED_IN_SUB_SAMPLE_FOR_OTOLITH
NO_PER_SEX_MEASURED_IN_SUB_SAMPLE_FOR_WEIGHT
NO_PER_SEX_MEASURED_IN_SUBSAMPLE_FOR_AGEING
These fields are compared to the number of records present in TE by sex, length class and haul.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.
wd <- tempdir() suffix="2020-03-05_time_h17m44s55" DataTE = RoME::TE year=2012 check_nb_TE(DataTE,year, wd, suffix)
Run the code above in your browser using DataLab