Learn R Programming

RoME (version 0.2.4)

check_nbtotTB: Check total number of individuals in TB

Description

The function checks that the total number of individuals is consistent with the sum of the individuals per sex

Usage

check_nbtotTB(DataTB, year, wd, suffix)

Value

The function returns TRUE if no error occurs, FALSE if one or more inconsistencies in the individuals number is detected.

Arguments

DataTB

Catch data table according to MEDITS protocol (TB)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

I. Bitetto, W. Zupa

Details

The function checks that the total number of individuals is consistent with the sum of the individuals per sex

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
    wd <- tempdir()
    suffix="2020-03-05_time_h17m44s55"
    DataTB = RoME::TB
    year=2007
    check_nbtotTB(DataTB,year, wd, suffix)

Run the code above in your browser using DataLab