powered by
The function checks that the total number of individuals is consistent with the sum of the individuals per sex
check_nbtotTB(DataTB, year, wd, suffix)
The function returns TRUE if no error occurs, FALSE if one or more inconsistencies in the individuals number is detected.
Catch data table according to MEDITS protocol (TB)
reference year for the analysis
working directory path defined by the user
Suffix string of the Logfile
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.
wd <- tempdir() suffix="2020-03-05_time_h17m44s55" DataTB = RoME::TB year=2007 check_nbtotTB(DataTB,year, wd, suffix)
Run the code above in your browser using DataLab