Learn R Programming

RoME (version 0.2.4)

check_position: Plot of haul positions

Description

The function generate three different plots, haul start position, haul end position and start and end positions together.

Usage

check_position(DataTA, year, wd, suffix)

Value

The function generate three maps of the haul position that are stored in the Graph folder allocated in the user defined wd directory

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

W. Zupa, I. Bitetto

Details

The haul position maps are saved in the Graph directory allocated in the user defined wd directory.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
year=2007
check_position(RoME::TA,year,wd,suffix)

Run the code above in your browser using DataLab