powered by
The function generate three different plots, haul start position, haul end position and start and end positions together.
check_position(DataTA, year, wd, suffix)
The function generate three maps of the haul position that are stored in the Graph folder allocated in the user defined wd directory
Haul data table according to MEDITS protocol (TA)
reference year for the analysis
working directory path defined by the user
Suffix string of the Logfile
W. Zupa, I. Bitetto
The haul position maps are saved in the Graph directory allocated in the user defined wd directory.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.
wd <- tempdir() suffix="2020-03-05_time_h17m44s55" year=2007 check_position(RoME::TA,year,wd,suffix)
Run the code above in your browser using DataLab