View source: R/check_position_in_Med.r
| check_position_in_Med | R Documentation |
The function checks whether the position of the haul is in the Mediterranean Sea area or falls on the land.
check_position_in_Med(DataTA, year, wd, suffix)
DataTA |
Haul data table according to MEDITS protocol (TA) |
year |
reference year for the analysis |
wd |
working directory path defined by the user |
suffix |
Suffix string of the Logfile |
The function uses the haul_at_sea() function to check whether the position of the haul is in the Mediterranean Sea area or falls on the land.
The function returns a boolean value. It is FALSE in case one or more haul positions fall out of the Mediterranean Sea area defined by the shapefile MedSea included in the package.
W. Zupa, I. Bitetto
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm
wd <- tempdir()
suffix="2020-03-05_time h17m44s55"
DataTA = RoME::TA
year=2007
check_position_in_Med(DataTA, year, wd, suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.