Learn R Programming

RoME (version 0.2.4)

check_position_in_Med: Check of haul position in Mediterranean Sea

Description

The function checks whether the position of the haul is in the Mediterranean Sea area or falls on the land.

Usage

check_position_in_Med(DataTA, year, wd, suffix)

Value

The function returns a boolean value. It is FALSE in case one or more haul positions fall out of the Mediterranean Sea area defined by the shapefile MedSea included in the package.

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

W. Zupa, I. Bitetto

Details

The function uses the haul_at_sea() function to check whether the position of the haul is in the Mediterranean Sea area or falls on the land.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
    wd <- tempdir()
    suffix="2020-03-05_time h17m44s55"
    DataTA = RoME::TA
    year=2007
    check_position_in_Med(DataTA, year, wd, suffix)

Run the code above in your browser using DataLab