check_quadrant: Check start and end quadrant for each haul
Description
Function checking that the shooting quadrant and the hauling quadrant are the same.
Usage
check_quadrant(ResultDataTA,year,wd,suffix)
Value
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles" subdirectory of the "wd" user-defined directory.
Arguments
ResultDataTA
Haul data table according to MEDITS protocol (TA).
year
reference year for the analysis
wd
Working directory selected by the user.
suffix
Suffix string of the Logfile.
Author
I. Bitetto, W. Zupa
Details
The function returns a warning if shooting and hauling quadrant are not the same.
References
For the definition of the quadrants, please refer to:
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.