check_species_TBTC: Function checking if all the target species in the catch data table (TB) are in Biological data table (TC)
Description
This function verifies the presence of the target species (that is a subset of the all the species caught, reported in TB), in the TC table, where additional information (apart from number and weight) are collected.
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks.
Arguments
ResultTB
Catch data table(TB).
ResultTC
Biological data table (TC).
year
reference year for the analysis
DataSpecies
Information related to target species.
wd
Working directory selected by the user.
suffix
Suffix string of the Logfile.
Author
I. Bitetto, W. Zupa
Details
This function gives a warning message, thus the execution is not stopped when some target species are lacking in TC; the user is informed in the Logfile.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.