check_step_length_distr: The function verifies that in TC the length measures are reported with the correct precision.
Description
Fishes and cephalopods length classes must have full or half step (in case of LENGTH_CLASSES_CODE=1 only full). All the measures , must be integer numbers.
The function returns TRUE if no error occurs, while FALSE is returned when the step is not correctly used. In the logfile is reported the list of all the records in which the inconsistency is detected.
Arguments
ResultData
alternatively: Biological data table (TC) and Individual data table (TE).
year
reference year for the analysis
wd
Working directory selected by the user.
suffix
Suffix string of the Logfile.
Author
I. Bitetto, W. Zupa
Details
According to the MEDITS protocol, Fishes and cephalopods length measurement must collected full or half step and all the measures, must be integer numbers. Empty (NA) records in LENGHT_CLASS field are removed from the analysis being empty fields already detected by check_no_empty_fields function.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.