Learn R Programming

RoME (version 0.2.4)

check_subsampling: Function to warn the user about the presence of subsamples <0.1 of the total catch.

Description

Check if the sub-sample is smaller than the 10 percent of the total weight in the haul.

Usage

check_subsampling(ResultTC,year,wd,suffix)

Value

The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles" subdirectory of the "wd" user-defined directory.

Arguments

ResultTC

Biological data table (TC).

year

reference year for the analysis.

wd

Working directory selected by the user.

suffix

Suffix string of the Logfile.

Author

I. Bitetto, W. Zupa

Details

This function give a warning, reported in the Logfile, if the sub-sample is unusually small respect to the total catch of the species.

References

For the definition of the strata, please refer to: Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
TC = RoME::TC
year=2007
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
check_subsampling(TC,year,wd,suffix)

Run the code above in your browser using DataLab