check_temperature: Function to check the consistency of the temperature data stored in haul data table (TA).
Description
This function checks if the temperature by haul is in the range 10-30 Celsius degrees; moreover, a plot depth versus temperature is produced and stored in the Graph folder.
Usage
check_temperature(ResultDataTA,year,wd,suffix)
Value
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks. The presence of inconsistencies in the data is reported in the logfile stored in the "Logfiles" subdirectory of the "wd" user-defined directory.
Arguments
ResultDataTA
Haul data table according to MEDITS protocol (TA).
year
reference year for the analysis.
wd
Working directory selected by the user.
suffix
Suffix string of the Logfile.
Author
I. Bitetto, W. Zupa
Details
This check uses the temperature range 10-30 Celsius degrees to provide quantitative warning and a plot, automatically stored in Graphs, for a qualitative inspection of that temperature data respect to depth.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.