View source: R/check_unique_valid_haul.r
| check_unique_valid_haul | R Documentation |
Check the presence of unique valid haul codes.
check_unique_valid_haul(ResultDataTA,year,wd,suffix)
ResultDataTA |
Haul data table according to MEDITS protocol (TA). |
year |
reference year for the analysis. |
wd |
Working directory selected by the user. |
suffix |
Suffix string of the Logfile. |
This function produce an error, stopping the check procedure to avoid cascade errors.
The function returns TRUE if no error occurs, while FALSE is returned when there is more than one valid hauls. In the logfile is reported the list of all the records in which the inconsistency is detected.
I. Bitetto, W. Zupa
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp. https://www.sibm.it/MEDITS%202011/principaledownload.htm
TA = RoME::TA
year=2012
wd=tempdir()
suffix= "2020-03-05_time_h17m44s55"
check_unique_valid_haul(TA,year,wd,suffix)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.