The function returns TRUE if no error occurs, while FALSE is returned when there is more than one valid hauls. In the logfile is reported the list of all the records in which the inconsistency is detected.
Arguments
ResultDataTA
Haul data table according to MEDITS protocol (TA).
year
reference year for the analysis.
wd
Working directory selected by the user.
suffix
Suffix string of the Logfile.
Author
I. Bitetto, W. Zupa
Details
This function produce an error, stopping the check procedure to avoid cascade errors.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.