check_weight_tot_nb: Function to check if, when the weight is not null, also the number is not null.
Description
If total weight is different from 0, total number must be different from 0 (only if the category of the species is different from "E") and vice versa (for all faunistic categories).
Usage
check_weight_tot_nb(ResultDataTB,year,wd,suffix)
Value
The function returns always TRUE, because the outcome of the function is a warning that does not lock the execution of the 'RoME' checks.
Arguments
ResultDataTB
Catch data table according to MEDITS protocol (TB)
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
Author
I. Bitetto, W. Zupa
Details
In this check 'RoME' verifies if for the records with total weight not null, there is a total number not null, except for categories V, G, H, D and E, as reported in MEDITS manual.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.