create_haul: Function to create R-sufi file containing haul data.

View source: R/create_haul.r

create_haulR Documentation

Function to create R-sufi file containing haul data.

Description

This function reports the information contained in the haul data table (TA) from the MEDITS protocol to the format required by R-sufi (Rochet et al., 2004).

Usage

create_haul(ResultDataTA,year,wd,save=TRUE)

Arguments

ResultDataTA

Haul data table according to MEDITS protocol (TA)

year

reference year for the analysis

wd

working directory path defined by the user

save

boolean value to save the results in a csv file

Value

The function saves by default in the files R-Sufi folder the table traits in.csv format, with suffix of the year and GSA. If save parameter is FALSE the function returns the data frame as output.

Author(s)

I. Bitetto, W. Zupa

References

Rochet M. J., V. M. Trenkel, J. A. Bertrand & J.-C. Poulard, 2004. R routines for survey based fisheries population and community indicators (R-SUFI). Ifremer, Nantes. Limited distribution. Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.https://www.sibm.it/MEDITS%202011/principaledownload.htm

Examples

TA = RoME::TA
year = 2012
wd = tempdir()
create_haul(TA,year,wd,save=FALSE)

RoME documentation built on April 24, 2026, 1:07 a.m.