create_strata: Function to create R-sufi file containing strata surface data.
Description
This function reports the information contained in the stratification scheme for the selected area from the MEDITS protocol to the format required by R-sufi (Rochet et al., 2004).
Usage
create_strata(Stratification,AREA,wd,save=TRUE)
Value
The function saves automatically in the files R-Sufi folder the table strata in.csv format, with suffix of the year and GSA. If save parameter is FALSE the function returns the data frame as output.
Arguments
Stratification
Stratification scheme according to MEDITS protocol.
AREA
String of the GSA.
wd
Working directory selected by the user.
save
boolean value to save the results in a csv file
Author
I. Bitetto, W. Zupa
References
Rochet M. J., V. M. Trenkel, J. A. Bertrand & J.-C. Poulard, 2004. R routines for survey based fisheries population and community indicators (R-SUFI). Ifremer, Nantes. Limited distribution.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.