Learn R Programming

RoME (version 0.2.4)

dd.distance: Estimation of haul distance

Description

Function to estimate the hauls length using TA (table A, hauls data) with coordinates in the decimal degrees format (dd.ddd). The distances could be returned expressed in meters, kilometers and nautical miles.

Usage

dd.distance(data, unit = "m", verbose=TRUE)

Value

The function returns the vector of the distances expressed in the selected measure unit.

Arguments

data

data frame of the hauls data (TA, table A)

unit

string value indicating the measure unit of the distance. Allowed values: "m" for meters, "km" for kilometers and "NM" for nautical miles.

verbose

give verbose output reporting in the output the selected measure unit of the distance.

Author

Walter Zupa

Details

The TA file should be populated with coordinates in decimal degrees format.

Examples

Run this code
TA.dd <- MEDITS.to.dd(TA)
dd.distance(TA.dd, unit="km", verbose=FALSE)

Run the code above in your browser using DataLab