Function generating the error summary table.
error.table(check.df,check_without_errors,
check_without_warnings,checkName,table,Field,yea)The output of the function is the data frame check.df updated with the result of the check.
data frame of the checks
boolean variable reporting if errors were detected
boolean variable reporting if warnings were detected
string of the check name
reference table checked by the function
field checked by check dictionary
reference year
W. Zupa, I. Bitetto
The function generate the summary table of the errors detected by the RoMEcc function.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.