Learn R Programming

RoME (version 0.2.4)

graphs_TA: Function for qualitative checks of shooting depth, warp length and wing opening in Haul data table (TA).

Description

Qualitative control (by means of 2 graphs) of relation between shooting depth e warp opening and between warp length e wing opening

Usage

graphs_TA(DataTA, year, wd, suffix)

Value

Two graphs are stored in the Graphs folder in the wd user defined directory

Arguments

DataTA

Haul data table according to MEDITS protocol (TA)

year

reference year for the analysis

wd

working directory path defined by the user

suffix

Suffix string of the Logfile

Author

W. Zupa, I. Bitetto

Details

The function generate 2 graphs for qualitative controls.

References

Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.

Examples

Run this code
TA = RoME::TA
year = 2012
wd <- tempdir()
suffix="2020-03-05_time_h17m44s55"
graphs_TA(RoME::TA,year,wd,suffix)

Run the code above in your browser using DataLab