powered by
Qualitative control (by means of 2 graphs) of relation between shooting depth e warp opening and between warp length e wing opening
graphs_TA(DataTA, year, wd, suffix)
Two graphs are stored in the Graphs folder in the wd user defined directory
Haul data table according to MEDITS protocol (TA)
reference year for the analysis
working directory path defined by the user
Suffix string of the Logfile
W. Zupa, I. Bitetto
The function generate 2 graphs for qualitative controls.
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.
TA = RoME::TA year = 2012 wd <- tempdir() suffix="2020-03-05_time_h17m44s55" graphs_TA(RoME::TA,year,wd,suffix)
Run the code above in your browser using DataLab