Learn R Programming

RoME (version 0.2.4)

headers.conversion: Headers conversion for MEDITS tables

Description

Headers conversion for MEDITS tables

Usage

headers.conversion(table, type, verbose = FALSE)

Value

A data frame object is returned including the only allowed field

Arguments

table

data frame of the TX table

type

type of tables to be analysed. Allowed values: "TA","TB","TC","TE","TL"

verbose

boolean. If TRUE a message is printed.

Details

The functions allow to convert headers of table coming from RDBFIS data base to the MEDITS format expected from RoME package