Headers conversion for MEDITS tables
headers.conversion(table, type, verbose = FALSE)A data frame object is returned including the only allowed field
data frame of the TX table
type of tables to be analysed. Allowed values: "TA","TB","TC","TE","TL"
boolean. If TRUE a message is printed.
The functions allow to convert headers of table coming from RDBFIS data base to the MEDITS format expected from RoME package