This check has as output a table (automatically saved in the wd user defined directory) named sampling_individual_measures.csv where for each species are stored the number of length measurements, individual weights and number of otoliths taken by length class. This table is useful to the user to evaluate the coverage of the individual measurements collections in order to verify if the sampling is in line with the protocol and to understand how eventually improve the sampling procedure.
Arguments
DataTC
Biological data table according to MEDITS protocol (TC)
DataTE
Individual biological data table according to MEDITS protocol (TE)
year
reference year for the analysis
wd
working directory path defined by the user
suffix
Suffix string of the Logfile
Author
I. Bitetto, W. Zupa
Details
The function uses biological data and individual biological data to produce a table where for each species are stored the number of length measurements, individual weights and number of otoliths taken by length class.
References
Anonymus. 2017. MEDITS-Handbook. Version n. 9. MEDITS Working Group. 106 pp.